@@ -1,8 +1,8 @@
-import { randomFillSync } from 'crypto'
+import { webcrypto as crypto } from 'node:crypto'
 
-import { urlAlphabet } from './url-alphabet/index.js'
+import { urlAlphabet as scopedUrlAlphabet } from './url-alphabet/index.js'
 
-export { urlAlphabet }
+export { urlAlphabet } from './url-alphabet/index.js'
 
 // It is best to make fewer, larger requests to the crypto module to
 // avoid system call overhead. So, random numbers are generated in a
@@ -12,25 +12,25 @@ export { urlAlphabet }
 const POOL_SIZE_MULTIPLIER = 128
 let pool, poolOffset
 
-let fillPool = bytes => {
+function fillPool(bytes) {
   if (!pool || pool.length < bytes) {
     pool = Buffer.allocUnsafe(bytes * POOL_SIZE_MULTIPLIER)
-    randomFillSync(pool)
+    crypto.getRandomValues(pool)
     poolOffset = 0
   } else if (poolOffset + bytes > pool.length) {
-    randomFillSync(pool)
+    crypto.getRandomValues(pool)
     poolOffset = 0
   }
   poolOffset += bytes
 }
 
-export let random = bytes => {
+export function random(bytes) {
   // `-=` convert `bytes` to number to prevent `valueOf` abusing
   fillPool((bytes -= 0))
   return pool.subarray(poolOffset - bytes, poolOffset)
 }
 
-export let customRandom = (alphabet, defaultSize, getRandom) => {
+export function customRandom(alphabet, defaultSize, getRandom) {
   // First, a bitmask is necessary to generate the ID. The bitmask makes bytes
   // values closer to the alphabet size. The bitmask calculates the closest
   // `2^31 - 1` number, which exceeds the alphabet size.
@@ -65,10 +65,11 @@ export let customRandom = (alphabet, defaultSize, getRandom) => {
   }
 }
 
-export let customAlphabet = (alphabet, size = 21) =>
-  customRandom(alphabet, size, random)
+export function customAlphabet(alphabet, size = 21) {
+  return customRandom(alphabet, size, random)
+}
 
-export let nanoid = (size = 21) => {
+export function nanoid(size = 21) {
   // `-=` convert `size` to number to prevent `valueOf` abusing
   fillPool((size -= 0))
   let id = ''
@@ -77,9 +78,9 @@ export let nanoid = (size = 21) => {
     // It is incorrect to use bytes exceeding the alphabet size.
     // The following mask reduces the random byte in the 0-255 value
     // range to the 0-63 value range. Therefore, adding hacks, such
-    // as empty string fallback or magic numbers, is unneccessary because
+    // as empty string fallback or magic numbers, is unnecessary because
     // the bitmask trims bytes down to the alphabet size.
-    id += urlAlphabet[pool[i] & 63]
+    id += scopedUrlAlphabet[pool[i] & 63]
   }
   return id
 }
