@@ -1,29 +1,25 @@
 #!/usr/bin/env node
 
-import { uid as uidSecure } from 'uid/secure'
 import { v4 as lukeed4 } from '@lukeed/uuid'
 import { v4 as napiV4 } from '@napi-rs/uuid'
-import { v4 as uuid4 } from 'uuid'
 import benchmark from 'benchmark'
-import shortid from 'shortid'
-import uidSafe from 'uid-safe'
-import { uid } from 'uid'
-import crypto from 'crypto'
-import pico from 'picocolors'
+import crypto from 'node:crypto'
+import { styleText } from 'node:util'
 import rndm from 'rndm'
 import srs from 'secure-random-string'
+import shortid from 'shortid'
+import { uid } from 'uid'
+import uidSafe from 'uid-safe'
+import { uid as uidSecure } from 'uid/secure'
+import { v4 as uuid4 } from 'uuid'
 
-import {
-  customAlphabet as aCustomAlphabet,
-  nanoid as aNanoid
-} from '../async/index.js'
-import { nanoid, customAlphabet } from '../index.js'
+import { nanoid as browser } from '../index.browser.js'
+import { customAlphabet, nanoid } from '../index.js'
 import { nanoid as nonSecure } from '../non-secure/index.js'
 
 let suite = new benchmark.Suite()
 
 let nanoid2 = customAlphabet('1234567890abcdef-', 10)
-let asyncNanoid2 = aCustomAlphabet('1234567890abcdef-', 10)
 
 function formatNumber(number) {
   return String(number)
@@ -53,6 +49,9 @@ suite
   .add('customAlphabet', () => {
     nanoid2()
   })
+  .add('nanoid for browser', () => {
+    browser()
+  })
   .add('secure-random-string', () => {
     srs()
   })
@@ -62,38 +61,6 @@ suite
   .add('shortid', () => {
     shortid()
   })
-  .add('nanoid/async', {
-    defer: true,
-    fn(defer) {
-      aNanoid().then(() => {
-        defer.resolve()
-      })
-    }
-  })
-  .add('async customAlphabet', {
-    defer: true,
-    fn(defer) {
-      asyncNanoid2().then(() => {
-        defer.resolve()
-      })
-    }
-  })
-  .add('async secure-random-string', {
-    defer: true,
-    fn(defer) {
-      srs(() => {
-        defer.resolve()
-      })
-    }
-  })
-  .add('uid-safe', {
-    defer: true,
-    fn(defer) {
-      uidSafe(14).then(() => {
-        defer.resolve()
-      })
-    }
-  })
   .add('uid', () => {
     uid(32)
   })
@@ -106,11 +73,11 @@ suite
   .on('cycle', event => {
     let name = event.target.name.padEnd('async secure-random-string'.length)
     let hz = formatNumber(event.target.hz.toFixed(0)).padStart(10)
-    if (event.target.name === 'nanoid/async') {
-      name = '\nAsync:\n' + name
-    } else if (event.target.name === 'uid') {
+    if (event.target.name === 'uid') {
       name = '\nNon-secure:\n' + name
     }
-    process.stdout.write(`${name}${pico.bold(hz)}${pico.dim(' ops/sec')}\n`)
+    process.stdout.write(
+      `${name}${styleText('bold', hz)}${styleText('dim', ' ops/sec')}\n`
+    )
   })
   .run()
